==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebCircularProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebCircularProgressDescription } from "./WebCircularProgressDescription";
/**
 * @hidden
 */
var WebCircularProgressDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCircularProgressDescriptionMetadata, _super);
    function WebCircularProgressDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCircularProgressDescriptionMetadata.b = function (a) {
        if (WebCircularProgressDescriptionMetadata.a == null) {
            WebCircularProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCircularProgressDescriptionMetadata.c(WebCircularProgressDescriptionMetadata.a);
        }
        if (a.g(WebCircularProgressDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCircularProgressDescriptionMetadata.a);
    };
    WebCircularProgressDescriptionMetadata.c = function (a) {
        WebProgressBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:CircularProgress");
    };
    WebCircularProgressDescriptionMetadata.d = function (a) {
        WebCircularProgressDescriptionMetadata.b(a);
        a.u("WebCircularProgress", function () { return new WebCircularProgressDescription(); });
        a.t("WebCircularProgress", WebCircularProgressDescriptionMetadata.a);
    };
    WebCircularProgressDescriptionMetadata.$t = markType(WebCircularProgressDescriptionMetadata, 'WebCircularProgressDescriptionMetadata');
    WebCircularProgressDescriptionMetadata.a = null;
    return WebCircularProgressDescriptionMetadata;
}(Base));
export { WebCircularProgressDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCircularProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebCircularProgressDescription } from "./WebCircularProgressDescription";
/**
 * @hidden
 */
var WebCircularProgressDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCircularProgressDescriptionMetadata, _super);
    function WebCircularProgressDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCircularProgressDescriptionMetadata.b = function (a) {
        if (WebCircularProgressDescriptionMetadata.a == null) {
            WebCircularProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCircularProgressDescriptionMetadata.c(WebCircularProgressDescriptionMetadata.a);
        }
        if (a.j(WebCircularProgressDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCircularProgressDescriptionMetadata.a);
    };
    WebCircularProgressDescriptionMetadata.c = function (a) {
        WebProgressBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:CircularProgress");
        a.item("__tagNameWC", "String:igc-circular-progress");
    };
    WebCircularProgressDescriptionMetadata.d = function (a) {
        WebCircularProgressDescriptionMetadata.b(a);
        a.aa("WebCircularProgress", function () { return new WebCircularProgressDescription(); });
        a.z("WebCircularProgress", WebCircularProgressDescriptionMetadata.a);
    };
    WebCircularProgressDescriptionMetadata.$t = markType(WebCircularProgressDescriptionMetadata, 'WebCircularProgressDescriptionMetadata');
    WebCircularProgressDescriptionMetadata.a = null;
    return WebCircularProgressDescriptionMetadata;
}(Base));
export { WebCircularProgressDescriptionMetadata };
